@@ -1,19 +1,8 @@
 /*
- * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Mathias Kraus <k.hias@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "blockitem.h"
 #include "block.h"
@@ -55,6 +44,6 @@ void BlockItem::destructionAnimation()
         m_destructionTimer->stop();
         delete m_destructionTimer;
         m_destructionTimer = nullptr;
-        emit blockItemDestroyed(this);
+        Q_EMIT blockItemDestroyed(this);
     }
 }
