@@ -1,22 +1,11 @@
 /*
- * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * Copyright 2007-2008 Gaël Courcelle <gael.courcelle@gmail.com>
- * Copyright 2007-2008 Alexia Allanic <alexia_allanic@yahoo.fr>
- * Copyright 2007-2008 Johann Hingue <yoan1703@hotmail.fr>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Gaël Courcelle <gael.courcelle@gmail.com>
+    SPDX-FileCopyrightText: 2007-2008 Alexia Allanic <alexia_allanic@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Johann Hingue <yoan1703@hotmail.fr>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef BONUS_H
 #define BONUS_H
@@ -41,7 +30,7 @@ public:
     /**
       * Deletes the Bonus instance.
       */
-    ~Bonus();
+    ~Bonus() override;
 
     /**
       * Computes an action on a collision with the Player.
